aboutsummaryrefslogtreecommitdiff
path: root/src/lib/test_merchant_api.c
diff options
context:
space:
mode:
authorFlorian Dold <florian.dold@gmail.com>2018-01-30 01:38:28 +0100
committerFlorian Dold <florian.dold@gmail.com>2018-01-30 01:38:28 +0100
commita4bff93ef869bbcd0f425d1b424d9b307f601447 (patch)
tree579f8ff4a1333e9175b826240e28371a8e9356d0 /src/lib/test_merchant_api.c
parent4b47e3ac9fd0f69f6ab1a317ac03b828d0993cba (diff)
downloadmerchant-a4bff93ef869bbcd0f425d1b424d9b307f601447.tar.gz
merchant-a4bff93ef869bbcd0f425d1b424d9b307f601447.tar.bz2
merchant-a4bff93ef869bbcd0f425d1b424d9b307f601447.zip
use url instead of uri consistently
Diffstat (limited to 'src/lib/test_merchant_api.c')
-rw-r--r--src/lib/test_merchant_api.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/test_merchant_api.c b/src/lib/test_merchant_api.c
index 40b1f60b..d4f605fc 100644
--- a/src/lib/test_merchant_api.c
+++ b/src/lib/test_merchant_api.c
@@ -2195,7 +2195,7 @@ track_transaction_cb (void *cls,
* @param ec taler-specific error code
* @param tip_id which tip ID should be used to pickup the tip
* @param tip_expiration when does the tip expire (needs to be picked up before this time)
* @param exchange_uri at what exchange can the tip be picked up
*/
static void
tip_authorize_cb (void *cls,
@@ -2203,7 +2203,7 @@ tip_authorize_cb (void *cls,
enum TALER_ErrorCode ec,
const struct GNUNET_HashCode *tip_id,
struct GNUNET_TIME_Absolute tip_expiration,
- const char *exchange_uri)
+ const char *exchange_url)
{
struct InterpreterState *is = cls;
struct Command *cmd = &is->commands[is->ip];
@@ -2232,12 +2232,12 @@ tip_authorize_cb (void *cls,
if ( (MHD_HTTP_OK == http_status) &&
(TALER_EC_NONE == ec) )
{
- if (0 != strcmp (exchange_uri,
+ if (0 != strcmp (exchange_url,
EXCHANGE_URL))
{
GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
"Unexpected exchange URL %s to command %s\n",
- exchange_uri,
+ exchange_url,
cmd->label);
fail (is);
return;
@@ -2195,7 +2195,7 @@ track_transaction_cb (void *cls,
* @param tip_id which tip ID should be used to pickup the tip
* @param tip_expiration when does the tip expire (needs to be picked up before this time)
- * @param exchange_uri at what exchange can the tip be picked up
+ * @param exchange_url at what exchange can the tip be picked up
*/
static void